<?php
/**
 * Copyright since 2007 PrestaShop SA and Contributors
 * PrestaShop is an International Registered Trademark & Property of PrestaShop SA
 *
 * NOTICE OF LICENSE
 *
 * This source file is subject to the Open Software License (OSL 3.0)
 * that is bundled with this package in the file LICENSE.md.
 * It is also available through the world-wide-web at this URL:
 * https://opensource.org/licenses/OSL-3.0
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to license@prestashop.com so we can send you a copy immediately.
 *
 * DISCLAIMER
 *
 * Do not edit or add to this file if you wish to upgrade PrestaShop to newer
 * versions in the future. If you wish to customize PrestaShop for your
 * needs please refer to https://devdocs.prestashop.com/ for more information.
 *
 * @author    PrestaShop SA and Contributors <contact@prestashop.com>
 * @copyright Since 2007 PrestaShop SA and Contributors
 * @license   https://opensource.org/licenses/OSL-3.0 Open Software License (OSL 3.0)
 */
if (!defined('_PS_VERSION_')) {
    exit;
}
class RegistrationController extends RegistrationControllerCore
{
    /** @var bool */
    public $ssl = true;
    /** @var string */
    public $php_self = 'registration';
    /** @var bool */
    public $auth = false;

    public function checkAccess()
    {
        // If the customer is already logged and he got here by 'accident', we will redirect him away
        if ($this->context->customer->isLogged() && !$this->ajax) {
            $this->redirect_after = $this->authRedirection ? urlencode($this->authRedirection) : 'my-account';
            $this->redirect();
        }

        return parent::checkAccess();
    }

    public function initContent()
    {
        $should_redirect = false;
        $module_setting = json_decode(Configuration::get('KB_MOBILE_LOGIN'), true);
        if (Tools::isSubmit('submitCreate') || Tools::isSubmit('create_account')) {
            if (Tools::isSubmit('submitCreate')) {
                if ($module_setting['enable']) {
                    $kblastemailvalue = Tools::getValue('email');
                    if ($module_setting['show_mobile_on_registration']) {
                       /**
                         * Remove the use of Post in php file.
                         *  Now we are passing email from front through front_validation.js file 
                         *  ASFeb2024 Post_Change
                         *  @date 08-02-2024
                         *  @modifier Amit Singh
                         */
                    }
                }
            }
            $register_form = $this
                ->makeCustomerForm()
                ->setGuestAllowed(false)
                ->fillWith(Tools::getAllValues())
            ;
            if (Tools::isSubmit('submitCreate')) {
                $hookResult = array_reduce(
                    Hook::exec('actionSubmitAccountBefore', array(), null, true),
                    function ($carry, $item) {
                        return $carry && $item;
                    },
                    true
                );
                if ($hookResult && $register_form->submit()) {
                    $should_redirect = true;
                }
            }
            $this->context->smarty->assign(array('register_form' => $register_form->getProxy(), 'hook_create_account_top' => Hook::exec('displayCustomerAccountFormTop')));
            $this->setTemplate('customer/registration');
        }
        parent::initContent();
        if ($should_redirect && !$this->ajax) {
            $back = urldecode(Tools::getValue('back'));
            if (Tools::secureReferrer($back)) {
                $this->redirectWithNotifications($back);
            } else {
                if ($this->authRedirection) {
                    $back = $this->authRedirection;
                } elseif (!preg_match('/^[\w\-]+$/', $back)) {
                    $back = 'my-account';
                }
                $this->redirectWithNotifications('index.php?controller=' . urlencode($back));
            }
        }
    }
}